Learn R Programming

gtfsrouter (version 0.0.5)

gtfs_transfer_table: gtfs_transfer_table

Description

Construct a transfer table for a GTFS feed.

Usage

gtfs_transfer_table(
  gtfs,
  d_limit = 200,
  min_transfer_time = 120,
  network = NULL,
  network_times = FALSE
)

Value

Modified version of the gtfs input with additional transfers table.

Arguments

gtfs

A GTFS feed obtained from the extract_gtfs function.

d_limit

Upper straight-line distance limit in metres for transfers.

min_transfer_time

Minimum time in seconds for transfers; all values below this will be replaced with this value, particularly all those defining in-place transfers where stop longitudes and latitudes remain identical.

network

Optional Open Street Map representation of the street network encompassed by the GTFS feed (see Examples).

network_times

If TRUE, transfer times are calculated by routing throughout the underlying street network. If this is not provided as the net parameter, it will be automatically downloaded.

Examples

Run this code
# Use the following lines to extract a street network for a given GTFS feed.
# The result can then be passed as the `network` parameter.
if (FALSE) {
library (dodgr)
net <- dodgr_streetnet_sc (pts = gtfs$stops [, c ("stop_lon", "stop_lat")])
}

Run the code above in your browser using DataLab