Process a local GTFS data set with environmental variables described in
go_home into a condensed version for use in go_home and
go_to_work functions.
process_gtfs_local(expand = 2)The data set is reduced to the bounding box defined by the home and work stations, expanded by this multiple. If the function appears to behave strangely, try re-running this function with a higher value of this parameter.