Calculate a vector of headway values -- that is, time intervals between consecutive services -- for all routes between two specified stations.
gtfs_route_headway(
gtfs,
from,
to,
from_to_are_ids = FALSE,
grep_fixed = TRUE,
quiet = FALSE
)A single vector of integer values containing headways between all services across a single 24-hour period
A set of GTFS data returned from extract_gtfs or, for more efficient queries, pre-processed with gtfs_timetable.
Names, IDs, or approximate (lon, lat) coordinates of start
stations (as stop_name or stop_id entry in the stops table, or a vector
of two numeric values). See Note.
Corresponding Names, IDs, or coordinates of end station.
Set to TRUE to enable from and to parameter to
specify entries in stop_id rather than stop_name column of the stops
table.
If FALSE, match station names (when passed as character
string) with grep(..., fixed = FALSE), to allow use of grep expressions.
This is useful to refine matches in cases where desired stations may match
multiple entries.
If TRUE, display a progress bar
Other main:
gtfs_route(),
gtfs_traveltimes()