# Use the following lines to extract a street network for a given GTFS feed.
# The result can then be passed as the `network` parameter.
if (FALSE) {
library (dodgr)
net <- dodgr_streetnet_sc (pts = gtfs$stops [, c ("stop_lon", "stop_lat")])
}
Run the code above in your browser using DataLab